@@ -4,6 +4,7 @@ import psutil
 import uuid
 import pickle
 import functools
+import time
 
 from mindsdb_native.__about__ import __version__
 from mindsdb_native.libs.data_types.mindsdb_logger import MindsdbLogger
@@ -24,7 +25,7 @@ def _get_memory_optimizations(df):
 
     mem_usage_ratio = df_memory / total_memory
 
-    sample_for_analysis = mem_usage_ratio >= 0.1 or (df.shape[0] * df.shape[1]) > (3 * pow(10, 4))
+    sample_for_analysis = mem_usage_ratio >= 0.1 or (df.shape[0] * df.shape[1]) > pow(10, 4)
     disable_lightwood_transform_cache = mem_usage_ratio >= 0.2
 
     return sample_for_analysis, disable_lightwood_transform_cache
@@ -34,7 +35,7 @@ def _prepare_sample_settings(user_provided_settings,
                              sample_for_analysis):
     default_sample_settings = dict(
         sample_for_analysis=sample_for_analysis,
-        sample_margin_of_error=0.005,
+        sample_margin_of_error=0.01,
         sample_confidence_level=1 - 0.005,
         sample_percentage=None,
         sample_function=sample_data
@@ -272,7 +273,9 @@ class Predictor:
                 apply_to_columns = advanced_args.get('apply_to_columns', {}),
                 disable_column_importance = advanced_args.get('disable_column_importance', False),
                 split_models_on = advanced_args.get('split_models_on', []),
-                remove_target_outliers = advanced_args.get('remove_target_outliers', 0)
+                remove_target_outliers = advanced_args.get('remove_target_outliers', 0),
+                remove_columns_with_missing_targets = advanced_args.get('remove_columns_with_missing_targets', True),
+                learn_started_at = time.time(),
             )
 
             if len(light_transaction_metadata['split_models_on']) > 0 and not light_transaction_metadata['quick_learn']:
