@@ -1,3 +1,4 @@
+import json
 from copy import deepcopy
 
 from mindsdb_native.config import CONFIG
@@ -18,37 +19,17 @@ from mindsdb_native.libs.constants.mindsdb import (
     TRANSACTION_ANALYSE,
     TRANSACTION_LEARN
 )
+from mindsdb_native.libs.helpers.json_helpers import unnest_df
 
 
 class DataExtractor(BaseModule):
-    def _data_from_when(self):
-        """
-        :return:
-        """
-        when_conditions = self.transaction.hmd['when']
-
-        when_conditions_list = []
-        # here we want to make a list of the type  ( ValueForField1, ValueForField2,..., ValueForFieldN ), ...
-        for when_condition in when_conditions:
-            cond_list = [None] * len(self.transaction.lmd['columns'])  # empty list with blanks for values
-
-            for condition_col in when_condition:
-                col_index = self.transaction.lmd['columns'].index(condition_col)
-                cond_list[col_index] = when_condition[condition_col]
-
-            when_conditions_list.append(cond_list)
-
-        result = pd.DataFrame(when_conditions_list, columns=self.transaction.lmd['columns'])
-
-        return result
-
-    def _data_from_when_data(self):
-        df = self.transaction.hmd['when_data']
+    def _data_from_when_data(self, df):
         df = df.where((pd.notnull(df)), None)
 
         for col in self.transaction.lmd['columns']:
             if col not in df.columns:
                 df[col] = [None] * len(df)
+
         return df
 
     def _apply_sort_conditions_to_df(self, df):
@@ -90,10 +71,12 @@ class DataExtractor(BaseModule):
 
         if self.transaction.lmd['type'] == TRANSACTION_PREDICT:
             if self.transaction.hmd['when_data'] is not None:
-                df = self._data_from_when_data()
+                df = self.transaction.hmd['when_data']
             else:
-                # if no data frame yet, make one
-                df = self._data_from_when()
+                df = pd.DataFrame(self.transaction.hmd['when'])
+                df, _ = unnest_df(df)
+
+            df = self._data_from_when_data(df)
 
             if self.transaction.lmd['setup_args'] is not None and self.transaction.lmd['tss']['is_timeseries'] and self.transaction.lmd['use_database_history']:
                 self.log.warning('Using automatic database history sourcing, will be selecting rows from the same table you used to train the original model.')
@@ -164,7 +147,7 @@ class DataExtractor(BaseModule):
 
         if self.transaction.lmd['type'] == TRANSACTION_LEARN:
             for col_target in self.transaction.lmd['predict_columns']:
-                if col_target not in self.transaction.input_data.columns:
+                if col_target not in self.transaction.lmd['columns']:
                     err = 'Trying to predict column {column} but column not in source data'.format(column=col_target)
                     self.log.error(err)
                     self.transaction.error = True
@@ -177,18 +160,32 @@ class DataExtractor(BaseModule):
                 self.transaction.lmd['data_types'][col] = self.transaction.hmd['from_data'].data_types[col]
                 self.transaction.lmd['data_subtypes'][col] = self.transaction.hmd['from_data'].data_subtypes[col]
 
+    def _count_isna(self, df):
+        count = 0
+        for col in df.columns:
+            count += df[col].isna().sum()
+        return count
+
     def run(self):
         if self.transaction.hmd.get('from_data') is not None:
             self.transaction.lmd['data_source_name'] = self.transaction.hmd['from_data'].name()
 
         # --- Dataset gets randomized or sorted (if timeseries) --- #
-        result = self._get_prepared_input_df()
+        df = self._get_prepared_input_df()
         # --- Dataset gets randomized or sorted (if timeseries) --- #
 
+        # --- Replace -inf/inf values with None --- #
+        null_count_1 = self._count_isna(df)
+        df.replace([np.inf, -np.inf], np.nan, inplace=True)
+        null_count_2 = self._count_isna(df)
+        inf_count = (null_count_2 - null_count_1)
+        if inf_count > 0:
+            self.log.warning('Your dataset contains {} -inf/inf values, replacing them with None'.format(inf_count))
+        # --- Replace -inf/inf values with None --- #
+
         # --- Some information about the dataset gets transplanted into transaction level variables --- #
-        self.transaction.input_data.columns = [x for x in result.columns.values.tolist() if x != 'make_predictions']
-        self.transaction.lmd['columns'] = self.transaction.input_data.columns
-        self.transaction.input_data.data_frame = result
+        self.transaction.lmd['columns'] = [x for x in df.columns.values.tolist() if x != 'make_predictions']
+        self.transaction.input_data.data_frame = df
         # --- Some information about the dataset gets transplanted into transaction level variables --- #
 
         self._set_user_data_subtypes()
